package net.t2code.t2codelib.VELOCITY.api.yaml;

import com.velocitypowered.api.proxy.ProxyServer;
import com.velocitypowered.api.plugin.PluginContainer;
import ninja.leaping.configurate.ConfigurationNode;
import ninja.leaping.configurate.commented.CommentedConfigurationNode;
import ninja.leaping.configurate.yaml.YAMLConfigurationLoader;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.slf4j.Logger;


import java.io.IOException;
import java.nio.file.Path;
import java.util.ArrayList;
import java.util.List;

public class T2CVconfig {
    private final Path configPath;
    private final @NonNull YAMLConfigurationLoader loader;
    private CommentedConfigurationNode configNode;

    public T2CVconfig(Path configPath, ProxyServer proxy, PluginContainer pluginContainer, Logger logger) {
        this.configPath = configPath;
        loader = YAMLConfigurationLoader.builder().setPath(configPath).build();
        try {
            this.configNode = (CommentedConfigurationNode) loader.load();
        } catch (IOException e) {
            logger.error("Error loading configuration file {}", configPath.getFileName(), e);
        }
    }

    public void saveConfig() {
        try {
            loader.save(configNode);
        } catch (IOException e) {
            throw new RuntimeException("Error saving configuration file " + configPath.getFileName(), e);
        }
    }

    public void set(String path, Object value) {
        configNode.getNode((Object[]) path.split("\\.")).setValue(value);
    }

    public String select(String path) {
        return configNode.getNode((Object[]) path.split("\\.")).getString();
    }

    public int selectInt(String path) {
        return configNode.getNode((Object[]) path.split("\\.")).getInt();
    }

    public boolean selectBoolean(String path) {
        return configNode.getNode((Object[]) path.split("\\.")).getBoolean();
    }

    public double selectDouble(String path) {
        return configNode.getNode((Object[]) path.split("\\.")).getDouble();
    }

    public List<String> selectList(String path) {
        List<String> list = new ArrayList<>();
        ConfigurationNode node = configNode.getNode((Object[]) path.split("\\."));
        if (node.hasListChildren()) {
            for (ConfigurationNode child : node.getChildrenList()) {
                list.add(child.getString(""));
            }
        }
        return list;
    }

    public List<String> selectList(String prefix, String path) {
        List<String> output = new ArrayList<>();
        ConfigurationNode node = configNode.getNode((Object[]) path.split("\\."));
        if (node.hasListChildren()) {
            for (ConfigurationNode child : node.getChildrenList()) {
                output.add(prefix + child.getString());
            }
        }
        return output;
    }


    public void setList(List<String> value, String path) {
        configNode.getNode((Object[]) path.split("\\.")).setValue(value);
    }
}
