package net.t2code.t2codelib.VELOCITY.system.config;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

public class VelocityConfig {

    private static final String CONFIG_FILE = "plugin_config.yml";

    private String pluginName;
    private int maxConnections;
    private boolean isEnabled;
    private boolean debugMode;
    private int timeoutSeconds;

    public VelocityConfig(String pluginName, int maxConnections, boolean isEnabled, boolean debugMode, int timeoutSeconds) {
        this.pluginName = pluginName;
        this.maxConnections = maxConnections;
        this.isEnabled = isEnabled;
        this.debugMode = debugMode;
        this.timeoutSeconds = timeoutSeconds;
    }

    public static VelocityConfig loadConfig() {
        Path configFile = Paths.get(CONFIG_FILE);
        if (!Files.exists(configFile)) {
            // Default configuration if file doesn't exist
            return new VelocityConfig("MyPlugin", 100, true, false, 30);
        }

        try {
            // Read configuration from file
            String content = Files.readString(configFile);
            String[] lines = content.split("\\r?\\n");

            // Parse the configuration
            String pluginName = lines[0].split(":")[1].trim();
            int maxConnections = Integer.parseInt(lines[1].split(":")[1].trim());
            boolean isEnabled = Boolean.parseBoolean(lines[2].split(":")[1].trim());
            boolean debugMode = Boolean.parseBoolean(lines[3].split(":")[1].trim());
            int timeoutSeconds = Integer.parseInt(lines[4].split(":")[1].trim());

            return new VelocityConfig(pluginName, maxConnections, isEnabled, debugMode, timeoutSeconds);
        } catch (IOException | ArrayIndexOutOfBoundsException | NumberFormatException e) {
            e.printStackTrace();
            // Handle exception: default configuration or logging
            return new VelocityConfig("MyPlugin", 100, true, false, 30);
        }
    }

    public void saveConfig() {
        Path configFile = Paths.get(CONFIG_FILE);
        try {
            // Write configuration to file
            String configContent = "pluginName: " + pluginName + "\n"
                    + "maxConnections: " + maxConnections + "\n"
                    + "isEnabled: " + isEnabled + "\n"
                    + "debugMode: " + debugMode + "\n"
                    + "timeoutSeconds: " + timeoutSeconds + "\n";
            Files.writeString(configFile, configContent);

        } catch (IOException e) {
            e.printStackTrace();
            // Handle exception: logging or alerting
        }
    }

    // Getters and setters
    public String getPluginName() {
        return pluginName;
    }

    public void setPluginName(String pluginName) {
        this.pluginName = pluginName;
    }

    public int getMaxConnections() {
        return maxConnections;
    }

    public void setMaxConnections(int maxConnections) {
        this.maxConnections = maxConnections;
    }

    public boolean isEnabled() {
        return isEnabled;
    }

    public void setEnabled(boolean enabled) {
        isEnabled = enabled;
    }

    public boolean isDebugMode() {
        return debugMode;
    }

    public void setDebugMode(boolean debugMode) {
        this.debugMode = debugMode;
    }

    public int getTimeoutSeconds() {
        return timeoutSeconds;
    }

    public void setTimeoutSeconds(int timeoutSeconds) {
        this.timeoutSeconds = timeoutSeconds;
    }

    public static void main() {
        // Example usage:
        VelocityConfig config = VelocityConfig.loadConfig();
        System.out.println("Loaded Configuration:");
        System.out.println("Plugin Name: " + config.getPluginName());
        System.out.println("Max Connections: " + config.getMaxConnections());
        System.out.println("Is Enabled: " + config.isEnabled());
        System.out.println("Debug Mode: " + config.isDebugMode());
        System.out.println("Timeout Seconds: " + config.getTimeoutSeconds());

        // Modify configuration
        config.setMaxConnections(150);
        config.setEnabled(false);
        config.setDebugMode(true);
        config.setTimeoutSeconds(60);

        // Save configuration
        config.saveConfig();
        System.out.println("Configuration saved.");
    }
}
